@@ -38,7 +38,7 @@ def isCharacter(currentContent):
     if any(x in text for x in ["--", "!", "?", "@", "%"]):
         return False
 
-    if any(x in text[-1] for x in ["-", "."]):
+    if any(x in text[-1] for x in ["-"]):
         return False
 
     if any(x in text for x in [":"]):
